@@ -1,40 +1,42 @@
-( cd usr/lib ; rm -rf libkdejava.so )
-( cd usr/lib ; ln -sf libkdejava.so.1.0.0 libkdejava.so )
-( cd usr/lib ; rm -rf libqtjavasupport.so.1 )
-( cd usr/lib ; ln -sf libqtjavasupport.so.1.0.0 libqtjavasupport.so.1 )
-( cd usr/lib ; rm -rf libsmokeqt.so.1 )
-( cd usr/lib ; ln -sf libsmokeqt.so.1.2.2 libsmokeqt.so.1 )
-( cd usr/lib ; rm -rf libkdejava.so.1 )
-( cd usr/lib ; ln -sf libkdejava.so.1.0.0 libkdejava.so.1 )
-( cd usr/lib ; rm -rf libsmokeqt.so )
-( cd usr/lib ; ln -sf libsmokeqt.so.1.2.2 libsmokeqt.so )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf korundum.so.0 )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf korundum.so.0.0.0 korundum.so.0 )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf qtruby.so.0 )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf qtruby.so.0.0.0 qtruby.so.0 )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf qtruby.so )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf qtruby.so.0.0.0 qtruby.so )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf qui.so )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf qui.so.0.0.0 qui.so )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf qui.so.0 )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf qui.so.0.0.0 qui.so.0 )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf korundum.so )
-( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf korundum.so.0.0.0 korundum.so )
-( cd usr/lib ; rm -rf libqtjavasupport.so )
-( cd usr/lib ; ln -sf libqtjavasupport.so.1.0.0 libqtjavasupport.so )
-( cd usr/lib ; rm -rf libqtjava.so )
-( cd usr/lib ; ln -sf libqtjava.so.1.0.0 libqtjava.so )
-( cd usr/lib ; rm -rf libqtjava.so.1 )
-( cd usr/lib ; ln -sf libqtjava.so.1.0.0 libqtjava.so.1 )
-( cd usr/lib ; rm -rf libsmokekde.so.1 )
-( cd usr/lib ; ln -sf libsmokekde.so.1.2.2 libsmokekde.so.1 )
-( cd usr/lib ; rm -rf libsmokekde.so )
-( cd usr/lib ; ln -sf libsmokekde.so.1.2.2 libsmokekde.so )
-( cd usr/lib ; rm -rf libkjsembed.so )
-( cd usr/lib ; ln -sf libkjsembed.so.1.0.0 libkjsembed.so )
-( cd usr/lib ; rm -rf libkjsembed.so.1 )
-( cd usr/lib ; ln -sf libkjsembed.so.1.0.0 libkjsembed.so.1 )
 ( cd usr/bin ; rm -rf rbkdesh )
 ( cd usr/bin ; ln -sf rbqtsh rbkdesh )
 ( cd usr/bin ; rm -rf rbkdeapi )
 ( cd usr/bin ; ln -sf rbqtapi rbkdeapi )
+( cd usr/lib ; rm -rf libqtjavasupport.so )
+( cd usr/lib ; ln -sf libqtjavasupport.so.1.0.0 libqtjavasupport.so )
+( cd usr/lib ; rm -rf libqtjavasupport.so.1 )
+( cd usr/lib ; ln -sf libqtjavasupport.so.1.0.0 libqtjavasupport.so.1 )
+( cd usr/lib ; rm -rf libsmokeqt.so.1 )
+( cd usr/lib ; ln -sf libsmokeqt.so.1.2.2 libsmokeqt.so.1 )
+( cd usr/lib ; rm -rf libqtjava.so.1 )
+( cd usr/lib ; ln -sf libqtjava.so.1.0.0 libqtjava.so.1 )
+( cd usr/lib ; rm -rf libkonsolepart.so )
+( cd usr/lib ; ln -sf /usr/lib/kde3/libkonsolepart.so libkonsolepart.so )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf qui.so.0 )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf qui.so.0.0.0 qui.so.0 )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf qtruby.so.0 )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf qtruby.so.0.0.0 qtruby.so.0 )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf korundum.so.0 )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf korundum.so.0.0.0 korundum.so.0 )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf qui.so )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf qui.so.0.0.0 qui.so )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf korundum.so )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf korundum.so.0.0.0 korundum.so )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; rm -rf qtruby.so )
+( cd usr/lib/ruby/site_ruby/1.8/i486-linux ; ln -sf qtruby.so.0.0.0 qtruby.so )
+( cd usr/lib ; rm -rf libkjsembed.so.1 )
+( cd usr/lib ; ln -sf libkjsembed.so.1.0.0 libkjsembed.so.1 )
+( cd usr/lib ; rm -rf libsmokeqt.so )
+( cd usr/lib ; ln -sf libsmokeqt.so.1.2.2 libsmokeqt.so )
+( cd usr/lib ; rm -rf libqtjava.so )
+( cd usr/lib ; ln -sf libqtjava.so.1.0.0 libqtjava.so )
+( cd usr/lib ; rm -rf libkjsembed.so )
+( cd usr/lib ; ln -sf libkjsembed.so.1.0.0 libkjsembed.so )
+( cd usr/lib ; rm -rf libkdejava.so )
+( cd usr/lib ; ln -sf libkdejava.so.1.0.0 libkdejava.so )
+( cd usr/lib ; rm -rf libsmokekde.so )
+( cd usr/lib ; ln -sf libsmokekde.so.1.2.2 libsmokekde.so )
+( cd usr/lib ; rm -rf libsmokekde.so.1 )
+( cd usr/lib ; ln -sf libsmokekde.so.1.2.2 libsmokekde.so.1 )
+( cd usr/lib ; rm -rf libkdejava.so.1 )
+( cd usr/lib ; ln -sf libkdejava.so.1.0.0 libkdejava.so.1 )
